====================
sabr
====================

SABRmetrics calculator for Python

Requirement
====================

python 3.5+

Install
====================

    $ pip install sabr

Usage
====================

.. code-block:: python

    from sabr.stats import Stats

    h9 = Stats.hr9(26, 209.7)  # Yu Darvish(2013) HR/9

License
====================

MIT License http://opensource.org/licenses/MIT
